@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -95,6 +95,10 @@ typedef enum {
 	OFStringEncodingKOI8R,
 	/** KOI8-U */
 	OFStringEncodingKOI8U,
+	/** Windows-1250 */
+	OFStringEncodingWindows1250,
+	/** Code page 852 */
+	OFStringEncodingCodepage852,
 	/** Try to automatically detect the encoding */
 	OFStringEncodingAutodetect = -1
 } OFStringEncoding;
@@ -131,7 +135,7 @@ typedef void (^OFStringLineEnumerationBlock)(OFString *line, bool *stop);
 #endif
 
 /**
- * @class OFString OFString.h ObjFW/OFString.h
+ * @class OFString OFString.h ObjFW/ObjFW.h
  *
  * @brief A class for handling strings.
  */
@@ -919,6 +923,19 @@ typedef void (^OFStringLineEnumerationBlock)(OFString *line, bool *stop);
  */
 - (const char *)lossyCStringWithEncoding: (OFStringEncoding)encoding;
 
+/**
+ * @brief Returns the OFString as an insecure C string (meaning it can contain
+ *	  `\0`) in the specified encoding.
+ *
+ * The result is valid until the autorelease pool is released. If you want to
+ * use the result outside the scope of the current autorelease pool, you have to
+ * copy it.
+ *
+ * @param encoding The encoding for the C string
+ * @return The OFString as a C string in the specified encoding
+ */
+- (const char *)insecureCStringWithEncoding: (OFStringEncoding)encoding;
+
 /**
  * @brief Returns the number of bytes the string needs in the specified
  *	  encoding.
@@ -1335,11 +1352,21 @@ extern OFStringEncoding OFStringEncodingParseName(OFString *name);
  */
 extern OFString *_Nullable OFStringEncodingName(OFStringEncoding encoding);
 
-extern char *_Nullable OFStrDup(const char *_Nonnull);
-extern size_t OFUTF8StringEncode(OFUnichar, char *);
-extern ssize_t OFUTF8StringDecode(const char *, size_t, OFUnichar *);
-extern size_t OFUTF16StringLength(const OFChar16 *);
-extern size_t OFUTF32StringLength(const OFChar32 *);
+/**
+ * @brief Returns the length of the specified UTF-16 string.
+ *
+ * @param string The UTF-16 string
+ * @return The length of the specified UTF-16 string
+ */
+extern size_t OFUTF16StringLength(const OFChar16 *string);
+
+/**
+ * @brief Returns the length of the specified UTF-32 string.
+ *
+ * @param string The UTF-32 string
+ * @return The length of the specified UTF-32 string
+ */
+extern size_t OFUTF32StringLength(const OFChar32 *string);
 #ifdef __cplusplus
 }
 #endif
